Manually constructed encoding tables
------------------------------------

`russup3.ucp`, `russup4ac.ucp`, `russup4na.ucp`: constructed based on gif images at https://web.archive.org/web/20061017214053/http://www.cyrillic.com/ref/cyrillic/

`dec-vt100.ucp`: rearranged from `dec-special` map

`manual/ibm897graph.ucp`: constructed based on information at https://en.wikipedia.org/wiki/Code_page_897

`windows-1.0.txt`, `windows-2.0.txt`, `windows-3.0.txt`: constructed based on information at https://www.aivosto.com/articles/charsets-codepages-windows.html

`ido2047.txt`:; based on information at https://en.wikipedia.org/wiki/ISO_2047

`hp48.txt`: constructed based on information at https://web.archive.org/web/20181108035237/http://www.kreativekorp.com/charset/encoding.php?name=HP48


> Insofar as these mappings are considered a copyrightable work, to the extent possible under law,
> I waive all copyright and related or neighbouring rights to that work under the
> [Creative Commons Zero dedication](http://creativecommons.org/publicdomain/zero/1.0/).
